# Cassandra Reaper API

[![PyPI - Version](https://img.shields.io/pypi/v/cassandra-reaper-api.svg)](https://pypi.org/project/cassandra-reaper-api)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cassandra-reaper-api.svg)](https://pypi.org/project/cassandra-reaper-api)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install cassandra-reaper-api
```

## License

`cassandra-reaper-api` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
